==> eventsourcing-3.0.0.tar.gz: eventsourcing-3.0.0/eventsourcing/__init__.py <==
"""
===============
Interface layer
===============

:mod:`eventsourcing.interface.notificationlog`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.interface.notificationlog
    :members:
    :show-inheritance:
    :undoc-members:


=================
Application layer
=================

:mod:`eventsourcing.application.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.application.base
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.application.policies`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.application.policies
    :members:
    :show-inheritance:
    :undoc-members:


============
Domain layer
============

:mod:`eventsourcing.domain.model.aggregate`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.aggregate
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.array`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.array
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.decorators`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.decorators
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.entity`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.entity
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.events`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.events
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.snapshot`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.snapshot
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.services.aes_cipher`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.services.aes_cipher
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.services.cipher`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.services.cipher
    :members:
    :show-inheritance:
    :undoc-members:



====================
Infrastructure layer
====================

:mod:`eventsourcing.infrastructure.eventsourcedrepository`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventsourcedrepository
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.eventplayer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventplayer
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.snapshotting`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.snapshotting
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.eventstore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventstore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sequenceditem`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sequenceditem
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sequenceditemmapper`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sequenceditemmapper
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.transcoding`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.transcoding
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.activerecord`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.activerecord
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cassandra.activerecords`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cassandra.activerecords
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cassandra.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cassandra.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sqlalchemy.activerecords`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sqlalchemy.activerecords
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sqlalchemy.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sqlalchemy.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.iterators`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.iterators
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.repositories.array`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.repositories.array
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.integersequencegenerators.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.integersequencegenerators.base
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.integersequencegenerators.redisincr`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.integersequencegenerators.redisincr
    :members:
    :show-inheritance:
    :undoc-members:




=================
Exception classes
=================

.. automodule:: eventsourcing.exceptions
    :members:
    :show-inheritance:
    :undoc-members:


===================
Example application
===================

:mod:`eventsourcing.example.interface.flaskapp`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.interface.flaskapp
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.application`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.application
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.domainmodel`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.domainmodel
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.infrastructure`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.infrastructure
    :members:
    :show-inheritance:
    :undoc-members:


"""

__version__ = '3.0.0'

==> eventsourcing-3.1.0.tar.gz: eventsourcing-3.1.0/eventsourcing/__init__.py <==
"""
===============
Interface layer
===============

:mod:`eventsourcing.interface.notificationlog`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.interface.notificationlog
    :members:
    :show-inheritance:
    :undoc-members:


=================
Application layer
=================

:mod:`eventsourcing.application.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.application.base
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.application.policies`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.application.policies
    :members:
    :show-inheritance:
    :undoc-members:


============
Domain layer
============

:mod:`eventsourcing.domain.model.aggregate`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.aggregate
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.array`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.array
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.decorators`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.decorators
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.entity`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.entity
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.events`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.events
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.domain.model.snapshot`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.domain.model.snapshot
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cipher.aes`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cipher.aes
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cipher.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cipher.base
    :members:
    :show-inheritance:
    :undoc-members:



====================
Infrastructure layer
====================

:mod:`eventsourcing.infrastructure.eventsourcedrepository`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventsourcedrepository
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.eventplayer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventplayer
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.snapshotting`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.snapshotting
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.eventstore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.eventstore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sequenceditem`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sequenceditem
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sequenceditemmapper`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sequenceditemmapper
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.transcoding`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.transcoding
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.activerecord`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.activerecord
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cassandra.activerecords`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cassandra.activerecords
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.cassandra.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.cassandra.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sqlalchemy.activerecords`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sqlalchemy.activerecords
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.sqlalchemy.datastore`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.sqlalchemy.datastore
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.iterators`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.iterators
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.repositories.array`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.repositories.array
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.integersequencegenerators.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.integersequencegenerators.base
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.infrastructure.integersequencegenerators.redisincr`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.infrastructure.integersequencegenerators.redisincr
    :members:
    :show-inheritance:
    :undoc-members:




=================
Exception classes
=================

.. automodule:: eventsourcing.exceptions
    :members:
    :show-inheritance:
    :undoc-members:


===================
Example application
===================

:mod:`eventsourcing.example.interface.flaskapp`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.interface.flaskapp
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.application`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.application
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.domainmodel`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.domainmodel
    :members:
    :show-inheritance:
    :undoc-members:


:mod:`eventsourcing.example.infrastructure`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: eventsourcing.example.infrastructure
    :members:
    :show-inheritance:
    :undoc-members:


"""

__version__ = '3.1.0'
